concat_

Macro concat_ 

macro_rules! concat_ {
    ($($part:expr),+ $(,)?) => { ... };
}
Macro to create a Concat from mixed Expressive arguments.

Each argument has .expr() called on it automatically, so you can pass Identifier, &str, vendor expressions, etc. directly.

concat_sql!(
    ident("path").dot_of("dt"),
    " > ",
    ident("name").dot_of("d")
)