pub struct Expression<T> {
pub template: String,
pub parameters: Vec<ExpressiveEnum<T>>,
}Expand description
Owned expression contains template and Vec of IntoExpressive parameters
Fields
template: Stringparameters: Vec<ExpressiveEnum<T>>Implementations
Sourceimpl<T> Expression<T>
impl<T> Expression<T>
Sourcepub fn new(
template: impl Into<String>,
parameters: Vec<ExpressiveEnum<T>>,
) -> Expression<T>
pub fn new( template: impl Into<String>, parameters: Vec<ExpressiveEnum<T>>, ) -> Expression<T>
Create a new owned expression with template and parameters
Sourcepub fn empty() -> Expression<T>
pub fn empty() -> Expression<T>
Create an empty expression that renders as “”.
Sourcepub fn from_vec(vec: Vec<Expression<T>>, delimiter: &str) -> Expression<T>
pub fn from_vec(vec: Vec<Expression<T>>, delimiter: &str) -> Expression<T>
Create expression from vector of expressions and a delimiter
See the module-level documentation for examples.
Sourceimpl<T> Expression<T>
impl<T> Expression<T>
Sourcepub fn as_type<U>(self) -> Expression<U>
pub fn as_type<U>(self) -> Expression<U>
Explicitly convert this expression to a different type.
Maps all scalar parameters via Into<U>. Useful for crossing type
boundaries — e.g. converting Expression<i64> from a typed column
operation into Expression<AnySqliteType> so it can be chained
with operations on other types.
ⓘ
let price = Column::<i64>::new("price");
price.gt(10) // Expression<i64>
.as_type::<AnySqliteType>() // Expression<AnySqliteType>
.eq(false) // now bool is acceptedTrait Implementations
Sourceimpl<T> Add for Expression<T>
impl<T> Add for Expression<T>
Sourcetype Output = Expression<T>
type Output = Expression<T>
The resulting type after applying the
+ operator.Sourcefn add(self, rhs: Expression<T>) -> <Expression<T> as Add>::Output
fn add(self, rhs: Expression<T>) -> <Expression<T> as Add>::Output
Performs the
+ operation. Read moreSourceimpl<T> Clone for Expression<T>where
T: Clone,
impl<T> Clone for Expression<T>where
T: Clone,
Sourcefn clone(&self) -> Expression<T>
fn clone(&self) -> Expression<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T> Debug for Expression<T>
impl<T> Debug for Expression<T>
Sourceimpl<T> Div for Expression<T>
impl<T> Div for Expression<T>
Sourcetype Output = Expression<T>
type Output = Expression<T>
The resulting type after applying the
/ operator.Sourcefn div(self, rhs: Expression<T>) -> <Expression<T> as Div>::Output
fn div(self, rhs: Expression<T>) -> <Expression<T> as Div>::Output
Performs the
/ operation. Read moreSourceimpl<From> ExpressionMap<From> for Expression<From>
impl<From> ExpressionMap<From> for Expression<From>
Sourceimpl<From, To> ExpressionMapper<From, To> for Expression<From>
impl<From, To> ExpressionMapper<From, To> for Expression<From>
Sourcefn map_expression(expr: Expression<From>) -> Expression<To>
fn map_expression(expr: Expression<From>) -> Expression<To>
Convert
Expression<From> to Expression<To>Sourceimpl<T> Expressive<T> for Expression<T>where
T: Clone,
impl<T> Expressive<T> for Expression<T>where
T: Clone,
Sourceimpl<F> From<Expression<F>> for SqliteCondition
impl<F> From<Expression<F>> for SqliteCondition
Sourcefn from(expr: Expression<F>) -> Self
fn from(expr: Expression<F>) -> Self
Converts to this type from the input type.
Sourceimpl From<Identifier> for Expression<AnySqliteType>
Available on crate feature sqlite only.
impl From<Identifier> for Expression<AnySqliteType>
Available on crate feature
sqlite only.Sourcefn from(id: Identifier) -> Self
fn from(id: Identifier) -> Self
Converts to this type from the input type.
Sourceimpl From<MockSelect> for Expression<Value>
impl From<MockSelect> for Expression<Value>
Sourcefn from(val: MockSelect) -> Expression<Value>
fn from(val: MockSelect) -> Expression<Value>
Converts to this type from the input type.
Sourceimpl From<SqliteCondition> for Expression<AnySqliteType>
impl From<SqliteCondition> for Expression<AnySqliteType>
Sourcefn from(cond: SqliteCondition) -> Self
fn from(cond: SqliteCondition) -> Self
Converts to this type from the input type.
Sourceimpl From<SqliteDelete> for Expression<AnySqliteType>
impl From<SqliteDelete> for Expression<AnySqliteType>
Sourcefn from(delete: SqliteDelete) -> Self
fn from(delete: SqliteDelete) -> Self
Converts to this type from the input type.
Sourceimpl From<SqliteIdent> for Expression<AnySqliteType>
impl From<SqliteIdent> for Expression<AnySqliteType>
Sourcefn from(id: SqliteIdent) -> Self
fn from(id: SqliteIdent) -> Self
Converts to this type from the input type.
Sourceimpl From<SqliteInsert> for Expression<AnySqliteType>
impl From<SqliteInsert> for Expression<AnySqliteType>
Sourcefn from(insert: SqliteInsert) -> Self
fn from(insert: SqliteInsert) -> Self
Converts to this type from the input type.
Sourceimpl From<SqliteUpdate> for Expression<AnySqliteType>
impl From<SqliteUpdate> for Expression<AnySqliteType>
Sourcefn from(update: SqliteUpdate) -> Self
fn from(update: SqliteUpdate) -> Self
Converts to this type from the input type.
Sourceimpl<T> Mul for Expression<T>
impl<T> Mul for Expression<T>
Sourcetype Output = Expression<T>
type Output = Expression<T>
The resulting type after applying the
* operator.Sourcefn mul(self, rhs: Expression<T>) -> <Expression<T> as Mul>::Output
fn mul(self, rhs: Expression<T>) -> <Expression<T> as Mul>::Output
Performs the
* operation. Read moreSourceimpl<T> OrderByExt<Expression<T>> for Expression<T>
impl<T> OrderByExt<Expression<T>> for Expression<T>
Sourcefn ascending(&self) -> OrderBy<Expression<T>>
fn ascending(&self) -> OrderBy<Expression<T>>
Create an ascending order specification
Sourcefn descending(&self) -> OrderBy<Expression<T>>
fn descending(&self) -> OrderBy<Expression<T>>
Create a descending order specification
Sourceimpl<T> Sub for Expression<T>
impl<T> Sub for Expression<T>
Sourcetype Output = Expression<T>
type Output = Expression<T>
The resulting type after applying the
- operator.Sourcefn sub(self, rhs: Expression<T>) -> <Expression<T> as Sub>::Output
fn sub(self, rhs: Expression<T>) -> <Expression<T> as Sub>::Output
Performs the
- operation. Read moreAuto Trait Implementations
impl<T> Freeze for Expression<T>
impl<T> !RefUnwindSafe for Expression<T>
impl<T> Send for Expression<T>where
T: Send,
impl<T> Sync for Expression<T>where
T: Sync,
impl<T> Unpin for Expression<T>where
T: Unpin,
impl<T> UnsafeUnpin for Expression<T>
impl<T> !UnwindSafe for Expression<T>